@@ -34,10 +34,10 @@ precedence_matrix <- function(eventlog, type = c("absolute","relative","relative
 		summarize(ts = min(timestamp_classifier))  %>%
 		group_by(case_classifier) %>%
 		arrange(ts) %>%
-		ungroup() %>%
-		transmute(case_classifier = case_classifier,
-				  antecedent = event_classifier,
+		mutate(antecedent = event_classifier,
 				  consequent = lead(event_classifier)) %>%
+		ungroup() %>%
+		select(antecedent, consequent) %>%
 		na.omit() %>%
 		count(antecedent, consequent) %>%
 		ungroup() -> log
